===============================
UKMDB Settings
===============================

.. image:: https://img.shields.io/pypi/v/ukmdb_settings.svg
        :target: https://pypi.python.org/pypi/ukmdb_settings

.. image:: https://img.shields.io/travis/mleist/ukmdb_settings.svg
        :target: https://travis-ci.org/mleist/ukmdb_settings

.. image:: https://readthedocs.org/projects/ukmdb_settings/badge/?version=latest
        :target: https://readthedocs.org/projects/ukmdb_settings/?badge=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/l/ukmdb_settings.svg

.. image:: https://img.shields.io/pypi/pyversions/ukmdb_settings.svg

.. image:: https://img.shields.io/pypi/status/ukmdb_settings.svg

.. image:: https://img.shields.io/pypi/dm/ukmdb_settings.svg


Settings module in context of UKMDB.

* Free software: GPLv3 license
* Documentation: https://ukmdb_settings.readthedocs.org.

Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
